@@ -20,8 +20,13 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <string>
+
 extern bool configurationChanged;
 
+extern std::string TimeSpanToString(size_t seconds, long microseconds);
+extern std::wstring TimeSpanToWString(size_t seconds, long microseconds);
+
 extern bool LoadConfig();
 extern bool SaveConfig();
 
